==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/processing/src/main/java/org/apache/druid/segment/column/BaseColumn.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.column;

import org.apache.druid.java.util.common.UOE;
import org.apache.druid.segment.ColumnValueSelector;
import org.apache.druid.segment.data.ReadableOffset;
import org.apache.druid.segment.vector.ReadableVectorOffset;
import org.apache.druid.segment.vector.VectorObjectSelector;
import org.apache.druid.segment.vector.VectorValueSelector;

import javax.annotation.Nullable;
import java.io.Closeable;

public interface BaseColumn extends Closeable
{
  ColumnValueSelector<?> makeColumnValueSelector(ReadableOffset offset);

  default VectorValueSelector makeVectorValueSelector(ReadableVectorOffset offset)
  {
    throw new UOE("Cannot make VectorValueSelector for column with class[%s]", getClass().getName());
  }

  default VectorObjectSelector makeVectorObjectSelector(ReadableVectorOffset offset)
  {
    throw new UOE("Cannot make VectorObjectSelector for column with class[%s]", getClass().getName());
  }

  @SuppressWarnings("unused")
  @Nullable
  default <T> T as(Class<? extends T> clazz)
  {
    return null;
  }
}

==> apache-druid-35.0.0-src.tar.gz: apache-druid-35.0.0-src/processing/src/main/java/org/apache/druid/segment/column/BaseColumn.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.column;

import org.apache.druid.java.util.common.UOE;
import org.apache.druid.segment.ColumnValueSelector;
import org.apache.druid.segment.data.ReadableOffset;
import org.apache.druid.segment.vector.ReadableVectorOffset;
import org.apache.druid.segment.vector.VectorObjectSelector;
import org.apache.druid.segment.vector.VectorValueSelector;

import java.io.Closeable;

public interface BaseColumn extends SelectableColumn, Closeable
{
  ColumnValueSelector<?> makeColumnValueSelector(ReadableOffset offset);

  default VectorValueSelector makeVectorValueSelector(ReadableVectorOffset offset)
  {
    throw new UOE("Cannot make VectorValueSelector for column with class[%s]", getClass().getName());
  }

  default VectorObjectSelector makeVectorObjectSelector(ReadableVectorOffset offset)
  {
    throw new UOE("Cannot make VectorObjectSelector for column with class[%s]", getClass().getName());
  }
}
